import { __decorate } from "tslib";
import { accentPalette, baseLayerLuminance, neutralPalette } from '@microsoft/fast-components';
import { customElement, FASTElement, observable } from '@microsoft/fast-element';
import { paletteFromColor } from '../../utils/utils';
import { EventName } from '../design-system-editor';
import { ColorStyles as styles } from './color-tokens.styles';
import { ColorTemplate as template } from './color-tokens.template';
let ColorTokens = class ColorTokens extends FASTElement {
    connectedCallback() {
        super.connectedCallback();
        document.body.addEventListener(EventName.STYLES_CHANGED, (e) => {
            const detail = e.detail;
            this.applyStyleChanges(detail);
        });
    }
    applyStyleChanges(detail) {
        baseLayerLuminance.setValueFor(this.provider, detail.luminance);
        const neutral = paletteFromColor(detail.neutralColor);
        neutralPalette.setValueFor(this.provider, neutral);
        const accent = paletteFromColor(detail.accentColor);
        accentPalette.setValueFor(this.provider, accent);
    }
};
__decorate([
    observable
], ColorTokens.prototype, "provider", void 0);
ColorTokens = __decorate([
    customElement({
        name: 'color-tokens',
        template,
        styles,
    })
], ColorTokens);
export { ColorTokens };
